@@ -6,7 +6,7 @@ use vars qw($VERSION $AUTOLOAD);
 use Carp;
 use Net::DNS;
 
-# $Id: Question.pm,v 1.4 1997/04/19 17:48:07 mfuhr Exp $
+# $Id: Question.pm,v 1.3 2002/05/14 10:51:23 ctriv Exp $
 $VERSION = $Net::DNS::VERSION;
 
 =head1 NAME
@@ -26,7 +26,7 @@ question section of a DNS packet.
 
 =head2 new
 
-    $question = new Net::DNS::Question("foo.com", "MX", "IN");
+    $question = Net::DNS::Question->new("example.com", "MX", "IN");
 
 Creates a question object from the domain, type, and class passed
 as arguments.
@@ -42,8 +42,26 @@ sub new {
 	);
 
 	my ($qname, $qtype, $qclass) = @_;
-	$self{"qname"} = $qname;
-	$self{"qtype"} = $qtype;
+
+	$qname  = "" if !defined($qname);
+
+	$qtype  = defined($qtype)  ? uc($qtype)  : "ANY";
+	$qclass = defined($qclass) ? uc($qclass) : "ANY";
+
+	# Check if the caller has the type and class reversed.
+	if ((!exists $Net::DNS::typesbyname{$qtype} ||
+	     !exists $Net::DNS::classesbyname{$qclass})
+	    && exists $Net::DNS::classesbyname{$qtype}
+	    && exists $Net::DNS::typesbyname{$qclass}) {
+
+		($qtype, $qclass) = ($qclass, $qtype);
+	}
+
+	$qname =~ s/^\.+//;
+	$qname =~ s/\.+$//;
+
+	$self{"qname"}  = $qname;
+	$self{"qtype"}  = $qtype;
 	$self{"qclass"} = $qclass;
 
 	bless \%self, $class;
@@ -58,6 +76,7 @@ sub DESTROY {}
 =head2 qname, zname
 
     print "qname = ", $question->qname, "\n";
+    print "zname = ", $question->zname, "\n";
 
 Returns the domain name.  In dynamic update packets, this field is
 known as C<zname> and refers to the zone name.
@@ -65,6 +84,7 @@ known as C<zname> and refers to the zone name.
 =head2 qtype, ztype
 
     print "qtype = ", $question->qtype, "\n";
+    print "ztype = ", $question->ztype, "\n";
 
 Returns the record type.  In dymamic update packets, this field is
 known as C<ztype> and refers to the zone type (must be SOA).
@@ -72,6 +92,7 @@ known as C<ztype> and refers to the zone type (must be SOA).
 =head2 qclass, zclass
 
     print "qclass = ", $question->qclass, "\n";
+    print "zclass = ", $question->zclass, "\n";
 
 Returns the record class.  In dynamic update packets, this field is
 known as C<zclass> and refers to the zone's class.
@@ -101,27 +122,40 @@ Prints the question record on the standard output.
 
 sub print {
 	my $self = shift;
-	print "$self->{qname}.\t$self->{qclass}\t$self->{qtype}\n";
+	print $self->string, "\n";
+}
+
+=head2 string
+
+    print $qr->string, "\n";
+
+Returns a string representation of the question record.
+
+=cut
+
+sub string {
+	my $self = shift;
+	return "$self->{qname}.\t$self->{qclass}\t$self->{qtype}";
 }
 
 =head2 data
 
-    $qdata = $question->data;
+    $qdata = $question->data($packet, $offset);
 
 Returns the question record in binary format suitable for inclusion
 in a DNS packet.
 
+Arguments are a C<Net::DNS::Packet> object and the offset within
+that packet's data where the C<Net::DNS::Question> record is to
+be stored.  This information is necessary for using compressed
+domain names.
+
 =cut
 
 sub data {
-	my $self = shift;
-	my $data = "";
+	my ($self, $packet, $offset) = @_;
 
-	my $elem;
-	foreach $elem (split(/\./, $self->{"qname"})) {
-		$data .= pack("C a*", length($elem), $elem);
-	}
-	$data .= pack("C", 0);
+	my $data = $packet->dn_comp($self->{"qname"}, $offset);
 
 	$data .= pack("n", $Net::DNS::typesbyname{uc($self->{"qtype"})});
 	$data .= pack("n", $Net::DNS::classesbyname{uc($self->{"qclass"})});
@@ -131,14 +165,14 @@ sub data {
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997 Michael Fuhr.  All rights reserved.  This program is free
-software; you can redistribute it and/or modify it under the same terms as
-Perl itself. 
+Copyright (c) 1997-2002 Michael Fuhr.  All rights reserved.  This
+program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself. 
 
 =head1 SEE ALSO
 
 L<perl(1)>, L<Net::DNS>, L<Net::DNS::Resolver>, L<Net::DNS::Packet>,
-L<Net::DNS::Header>, L<Net::DNS::RR>,
+L<Net::DNS::Update>, L<Net::DNS::Header>, L<Net::DNS::RR>,
 RFC 1035 Section 4.1.2
 
 =cut
