@@ -1,6 +1,6 @@
 package Net::DNS::RR::PTR;
 
-# $Id: PTR.pm,v 1.3 1997/06/13 03:33:54 mfuhr Exp $
+# $Id: PTR.pm,v 1.2 2002/02/13 03:53:59 ctriv Exp $
 
 use strict;
 use vars qw(@ISA);
@@ -20,6 +20,17 @@ sub new {
 	return bless $self, $class;
 }
 
+sub new_from_string {
+	my ($class, $self, $string) = @_;
+
+	if ($string) {
+		$string =~ s/\.+$//;
+		$self->{"ptrdname"} = $string;
+	}
+
+	return bless $self, $class;
+}
+
 sub rdatastr {
 	my $self = shift;
 
@@ -64,9 +75,9 @@ Returns the domain name associated with this record.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997 Michael Fuhr.  All rights reserved.  This program is free
-software; you can redistribute it and/or modify it under the same terms as
-Perl itself. 
+Copyright (c) 1997-1998 Michael Fuhr.  All rights reserved.  This
+program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself. 
 
 =head1 SEE ALSO
 
