@@ -1,6 +1,6 @@
 package Net::DNS::RR::SRV;
 
-# $Id: SRV.pm,v 1.3 1997/06/13 03:33:54 mfuhr Exp $
+# $Id: SRV.pm,v 1.2 2002/02/13 03:53:59 ctriv Exp $
 
 use strict;
 use vars qw(@ISA);
@@ -27,6 +27,20 @@ sub new {
 	return bless $self, $class;
 }
 
+sub new_from_string {
+	my ($class, $self, $string) = @_;
+
+	if ($string && ($string =~ /^(\d+)\s+(\d+)\s+(\d+)\s+(\S+)$/)) {
+		$self->{"priority"} = $1;
+		$self->{"weight"}   = $2;
+		$self->{"port"}     = $3;
+		$self->{"target"}   = $4;
+		$self->{"target"}   =~ s/\.+$//;
+	}
+
+	return bless $self, $class;
+}
+
 sub rdatastr {
 	my $self = shift;
 	my $rdatastr;
@@ -99,14 +113,14 @@ Returns the target host.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997 Michael Fuhr.  All rights reserved.  This program is free
-software; you can redistribute it and/or modify it under the same terms as
-Perl itself. 
+Copyright (c) 1997-2000 Michael Fuhr.  All rights reserved.  This
+program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself. 
 
 =head1 SEE ALSO
 
 L<perl(1)>, L<Net::DNS>, L<Net::DNS::Resolver>, L<Net::DNS::Packet>,
 L<Net::DNS::Header>, L<Net::DNS::Question>, L<Net::DNS::RR>,
-RFC 2052
+RFC 2782
 
 =cut
